# -*- coding: utf-8 -*-

# Vendor Library

# Project Library
from kinder.settings import logger
from kinder.core.async.tasks import AsyncTask
from kinder.core.declaration.models import Declaration
from concentrator.webservice.service import (
    send_update_application_state)


class SendUpdateApplicationState(AsyncTask):
    """Отправка информации о смене статуса в концентратор.
    :param declaration_id: ID завяления
    :param is_auto: Флаг автосмены статуса
    :param commentary: комментарий
    """

    description = u'Отправка информации о смене статуса в концентратор'

    def run(self, declaration_id, is_auto, commentary, log_id):
        """
        :param declaration_id: id заявления
        :param is_auto: авто-смена статуса при применении изменений из ЕПГУ
        :param commentary: комментарий пользователя при применение,
        либо отмене изменений
        :param log_id: идентификатор записи в логе о смене статуса заявления
        :return:
        """
        try:
            declaration = Declaration.objects.get(id=declaration_id)
        except Declaration.DoesNotExist:
            declaration = None

        send_update_application_state(
            declaration, is_auto=is_auto, commentary=commentary, log_id=log_id)

    def on_failure(self, exc, task_id, args, kwargs, einfo):
        logger.error(exc.message)
